@@ -3,11 +3,11 @@ from tensorflow.keras.preprocessing.image import img_to_array
 from tensorflow.keras.models import load_model
 import numpy as np
 import argparse
-import imutils
 import time
 import cv2
 import os
 import matplotlib.pyplot as plt
+import sys
 #from pretrained_models import get_model
 
 def detect_and_predict_mask(frame, faceNet, maskNet, args):
@@ -97,10 +97,10 @@ def main():
     # load our serialized face detector model from disk
     print("Loading face detector model...")
     prototxtPath = os.path.sep.join([args["face"], "deploy.prototxt"])
-    print(f'Path : {prototxtPath}')
+    #print(f'Path : {prototxtPath}')
     weightsPath = os.path.sep.join([args["face"],
         "res10_300x300_ssd_iter_140000.caffemodel"])
-    print(f'Weights path : {weightsPath}')
+    #print(f'Weights path : {weightsPath}')
     faceNet = cv2.dnn.readNet(prototxtPath, weightsPath)
 
     # load the face mask detector model from disk
@@ -110,6 +110,18 @@ def main():
     # load the input image from disk, clone it, and grab the image spatial
     # dimensions
     image = cv2.imread(args["image"])
+    mask_found = False
+
+    exit_txt = '''
+    ********************************************************
+    *** No valid image detected. Try again. Quitting ... ***
+    ********************************************************
+    ''' 
+
+    if image is None:
+        print(exit_txt)
+        sys.exit(0)
+
     orig = image.copy()
     (h, w) = image.shape[:2]
 
@@ -163,7 +175,6 @@ def main():
 
             # display the label and bounding box rectangle on the output
             # frame
-            mask_found = False
             if mask > withoutMask:
                 mask_found = True
                 cv2.putText(image, label, (startX, startY - 10),
@@ -175,22 +186,32 @@ def main():
     # show the output image depending on output
     output_file = 'image.jpg'
     original_file = 'original_image.jpg'
+    mask_txt = '''
+    *****************************************************************************
+    ******************************* HELMET DETECTED *****************************
+    *****************************************************************************
+    '''
+    no_mask_txt = '''
+    *****************************************************************************
+    ***************************** NO HELMET DETECTED ****************************
+    *****************************************************************************
+    '''
     if args["output"] == 'file':
         print(f'Writing out to {output_file}')
         cv2.imwrite(output_file, image)
         cv2.imwrite(original_file, orig)
         if mask_found:
-            print('Helmet detected')
+            print(mask_txt)
         else:
-            print('No helmet detected')
+            print(no_mask_txt)
     else:
         print(f'Writing out to display')
         if mask_found:
-            print('Helmet detected')
+            print(mask_txt)
         else:
-            print('No helmet detected')
+            print(no_mask_txt)
         cv2.imshow("Output", image)
         cv2.waitKey(0)
-
+    
 if __name__ == '__main__':
     main()
\ No newline at end of file
